==> AffyCompatible_1.0.1.tgz: AffyCompatible/doc/NetAffxResource.R <==
###################################################
### chunk number 1: setup
###################################################
library(AffyCompatible)


###################################################
### chunk number 2: rsrc-setup
###################################################
affxLicence <- "FHCRC0607"
password <- "jnkdna"


###################################################
### chunk number 3: rsrc
###################################################
rsrc <- NetAffxResource(user="mtmorgan@fhcrc.org", password=password,
                        affxLicence=affxLicence)
rsrc


###################################################
### chunk number 4: names
###################################################
head(names(rsrc))
affxDescription(rsrc[["Bovine"]])


###################################################
### chunk number 5: select-anno
###################################################
annos <- rsrc[["Porcine"]]
annos


###################################################
### chunk number 6: anno-class
###################################################
sapply(affxAnnotation(annos), force)[1:5]
anno <- affxAnnotation(annos)[[3]]
anno


###################################################
### chunk number 7: select-anno-idx
###################################################
anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
anno <- rsrc[["Porcine", 3]]


###################################################
### chunk number 8: readAnnotation
###################################################
df <- readAnnotation(rsrc, annotation=anno)


###################################################
### chunk number 9: anno-free-form
###################################################
anno <- rsrc[["Porcine", "PSI Library File"]]
fl <- readAnnotation(rsrc, annotation=anno, content=FALSE)
fl
## a zip file, containing 'Porcine.psi'
conn <- unz(fl, "Porcine.psi")
readLines(conn, n=6)
read.table(conn, header=FALSE, skip=1, sep="\t", nrows=5)

==> AffyCompatible_1.2.0.tgz: AffyCompatible/doc/NetAffxResource.R <==
###################################################
### chunk number 1: setup
###################################################
library(AffyCompatible)


###################################################
### chunk number 2: rsrc-setup
###################################################
password <- "jnkdna"


###################################################
### chunk number 3: rsrc
###################################################
rsrc <- NetAffxResource(user="mtmorgan@fhcrc.org", password=password)
rsrc


###################################################
### chunk number 4: names
###################################################
head(names(rsrc))
affxDescription(rsrc[["Bovine"]])


###################################################
### chunk number 5: select-anno
###################################################
annos <- rsrc[["Porcine"]]
annos


###################################################
### chunk number 6: anno-class
###################################################
sapply(affxAnnotation(annos), force)[1:5]
anno <- affxAnnotation(annos)[[3]]
anno


###################################################
### chunk number 7: select-anno-idx
###################################################
anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
anno <- rsrc[["Porcine", 3]]


###################################################
### chunk number 8: readAnnotation
###################################################
df <- readAnnotation(rsrc, annotation=anno)


###################################################
### chunk number 9: anno-free-form
###################################################
anno <- rsrc[["Porcine", "PSI Library File"]]
fl <- readAnnotation(rsrc, annotation=anno, content=FALSE)
fl
## a zip file, containing 'Porcine.psi'
conn <- unz(fl, "Porcine.psi")
readLines(conn, n=6)
read.table(conn, header=FALSE, skip=1, sep="\t", nrows=5)
